@@ -2,14 +2,14 @@
 #![cfg_attr(feature = "external_doc", feature(external_doc))]
 #![cfg_attr(feature = "external_doc", doc(include = "../README.md"))]
 
+extern crate alloc;
 extern crate proc_macro;
 extern crate proc_macro2;
-extern crate alloc;
 
+use alloc::{boxed::Box, format, string::String, vec, vec::Vec};
 use proc_macro::TokenStream;
 use quote::quote;
 use syn::{parse_macro_input, Data, DeriveInput};
-use alloc::{format, vec, vec::Vec, boxed::Box, string::String};
 
 macro_rules! die {
     ($ident:expr, $($reason:expr),+) => {{
@@ -74,6 +74,22 @@ pub fn derive_try_from_primitive(stream: TokenStream) -> TokenStream {
     TokenStream::from(expanded)
 }
 
+#[proc_macro_derive(UnsafeFromPrimitive)]
+pub fn derive_unsafe_from_primitive(stream: TokenStream) -> TokenStream {
+    let input = parse_macro_input!(stream as DeriveInput);
+    let EnumInfo { name, repr, .. } = parse_enum(input);
+
+    let expanded = quote! {
+        impl #name {
+            pub unsafe fn from_unchecked(num: #repr) -> Self {
+                ::core::intrinsics::transmute(num)
+            }
+        }
+    };
+
+    TokenStream::from(expanded)
+}
+
 struct EnumInfo {
     name: syn::Ident,
     repr: proc_macro2::Ident,
